"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.viaContentsApi = void 0;
const node_fetch_commonjs_1 = __importDefault(require("node-fetch-commonjs"));
async function api(endpoint, token) {
    const response = await (0, node_fetch_commonjs_1.default)(`https://api.github.com/repos/${endpoint}`, {
        headers: token
            ? {
                Authorization: `Bearer ${token}`,
            }
            : {},
    });
    return await response.json();
}
// Great for downloads with few sub directories on big repos
// Cons: many requests if the repo has a lot of nested dirs
async function viaContentsApi({ user, repository, ref = 'HEAD', directory, token, getFullData = false, }) {
    const files = [];
    const contents = (await api(`${user}/${repository}/contents/${directory}?ref=${ref}`, token));
    if ('message' in contents && contents.message === 'Not Found') {
        return [];
    }
    if ('message' in contents && contents.message) {
        throw new Error(contents.message);
    }
    for (const item of contents) {
        if (item.type === 'file') {
            files.push(getFullData ? item : item.path);
        }
        else if (item.type === 'dir') {
            files.push(getFullData ? item : item.path);
        }
    }
    return files;
}
exports.viaContentsApi = viaContentsApi;
